from setuptools import setup

setup(name='funniestjoke',
      version='0.2',
      description='The funniest joke in the world',
      url='http://github.com/purushothamkdr453/funniestjoke',
      author='purushotham reddy',
      author_email='purushothamkdr453@gmail.com',
      license='MIT',
      packages=['funniestjoke'],
      zip_safe=False)
